from mcpo_simple_server.services.config import get_config_service, set_config_service
from mcpo_simple_server.services.mcpserver import get_mcpserver_service, set_mcpserver_service


__all__ = [
    "get_config_service",
    "set_config_service",
    "get_mcpserver_service",
    "set_mcpserver_service"
]
